<?php

/**
 * @file
 * Theme functions for the jp_mobile theme.
 */

/**
 * Defines top and bottom regions instead of sidebars.
 */
function jp_mobile_regions() {
  return array(
    'content_top' => t('Content top'),
    'content_bottom' => t('Content bottom'),
  );
}

/**
 * Converts HTML entities to decimal forms for xml parsing.
 * Issues:
 * 1. It appears some html entities are missing from the translation table.
 * 2. Softbank emulator doesn't parse some characters in either html entity or numeric point form.
 * Hold back from using this function until the above issues are solved.
 *
 * @param $string
 *  A string containing html entities.
 * @return 
 *  A string containing html numeric code points.
 */
/*
function numeric_entities($string) {
  $mapping = array();
  foreach (get_html_translation_table(HTML_ENTITIES) as $char => $entity) {
    $mapping[$entity] = '&#' . ord($char) . ';';
  }
  return str_replace(array_keys($mapping), $mapping, $string);
}
 */

/**
 * Converts encoding from utf-8 to Shift JIS.
 */
function jp_mobile_page($content, $show_blocks = TRUE) {
  $output = phptemplate_page($content, $show_blocks);
  //convert to html entities those special characters which don't convert to Shift JIS from UTF-8
  //$output = mb_convert_encoding($output, 'html-entities', 'utf-8');
  $output = mb_convert_encoding($output, 'sjis', 'utf-8');
  //Softbank can't interpret numeric codes.
  $output = str_replace('&#039;', '\'', $output);
  return $output;
}

/**
 * Inserts Shift_JIS into accept-charset.
 */
function jp_mobile_form($element) {
  // Anonymous div to satisfy XHTML compliance.
  $action = $element['#action'] ? 'action="'. check_url($element['#action']) .'" ' : '';
  return '<form '. $action .' accept-charset="UTF-8;q=1, Shift_JIS;q=0.5" method="'. $element['#method'] .'" '. 'id="'. $element['#id'] .'"'. drupal_attributes($element['#attributes']) .">\n<div>". $element['#children'] ."\n</div></form>\n";
}

/**
 * Replaces raquo with '>>'.
 */
function jp_mobile_breadcrumb($breadcrumb) {
  if (!empty($breadcrumb)) {
    return '<div class="breadcrumb">'. implode(' &gt;&gt; ', $breadcrumb) .'</div>';
  }
}

/**
 * Replaces <ul> with <div>
 */
function jp_mobile_menu_local_tasks() {
  $output = '';

  if ($primary = menu_primary_local_tasks()) {
    $output .= "<div class=\"tabs primary\">\n". $primary ."</div>\n";
  }
  if ($secondary = menu_secondary_local_tasks()) {
    $output .= "<div class=\"tabs secondary\">\n". $secondary ."</div>\n";
  }

  return $output;
}

/**
 * Replaces <li> with <span> and adds a delimiter.
 */
function jp_mobile_menu_local_task($mid, $active, $primary) {
  if ($active) {
    return '<span class="active">'. menu_item_link($mid) ."</span> |\n";
  }
  else {
    return '<span>'. menu_item_link($mid) ."</span> |\n";
  }
}

/**
 * Replaces <ul> and <li> with <span>, and adds a link delimiter.
 */
function jp_mobile_links($links, $attributes = array('class' => 'links')) {
  $output = '';

  if (count($links) > 0) {
    $output = '<span'. drupal_attributes($attributes) .'>';

    $num_links = count($links);
    $i = 1;

    foreach ($links as $key => $link) {
      $class = $key;

      // Automatically add a class to each link and also to each LI
      if (isset($link['attributes']) && isset($link['attributes']['class'])) {
        $link['attributes']['class'] .= ' '. $key;
      }
      else {
        $link['attributes']['class'] = $key;
      }

      // Add first and last classes to the list of links to help out themers.
      $extra_class = '';
      if ($i == 1) {
        $extra_class .= 'first ';
      }
      if ($i == $num_links) {
        $extra_class .= 'last ';
      }
      //add delimiter between links.
      if ($i != 1) {
        $output .= '| ';
      }
      $output .= '<span '. drupal_attributes(array('class' => $extra_class . $class)) .'>';

      // Is the title HTML?
      $html = isset($link['html']) && $link['html'];

      // Initialize fragment and query variables.
      $link['query'] = isset($link['query']) ? $link['query'] : NULL;
      $link['fragment'] = isset($link['fragment']) ? $link['fragment'] : NULL;

      if (isset($link['href'])) {
        $output .= l($link['title'], $link['href'], $link['attributes'], $link['query'], $link['fragment'], FALSE, $html);
      }
      else if ($link['title']) {
        //Some links are actually not links, but we wrap these in <span> for adding title and class attributes
        if (!$html) {
          $link['title'] = check_plain($link['title']);
        }
        $output .= '<span'. drupal_attributes($link['attributes']) .'>'. $link['title'] .'</span>';
      }

      $i++;
      $output .= "</span>\n";
    }

    $output .= '</span>';
  }

  return $output;
}

/**
 *  Removes node titles and inserts inline CSS.
 */
function jp_mobile_book_navigation($node) {
  $output = '';
  $links = '';

  if ($node->nid) {
    $tree = book_tree($node->nid);

    if ($prev = book_prev($node)) {
      drupal_add_link(array('rel' => 'prev', 'href' => url('node/'. $prev->nid)));
      //$links .= l(t('‹ ') . $prev->title, 'node/'. $prev->nid, array('class' => 'page-previous', 'title' => t('Go to previous page')));
      $links .= l(t('&lt;   '), 'node/'. $prev->nid, array('class' => 'page-previous', 'title' => t('Go to previous page')), NULL, NULL, FALSE, TRUE);
    }
    if ($node->parent) {
      drupal_add_link(array('rel' => 'up', 'href' => url('node/'. $node->parent)));
      $links .= l(t('up'), 'node/'. $node->parent, array('class' => 'page-up', 'title' => t('Go to parent page')));
    }
    if ($next = book_next($node)) {
      drupal_add_link(array('rel' => 'next', 'href' => url('node/'. $next->nid)));
      //$links .= l($next->title . t(' ›'), 'node/'. $next->nid, array('class' => 'page-next', 'title' => t('Go to next page')));
      $links .= l(t('   &gt;'), 'node/'. $next->nid, array('class' => 'page-next', 'title' => t('Go to next page')), NULL, NULL, FALSE, TRUE);
    }

    if (isset($tree) || isset($links)) {
      $output = '<div class="book-navigation">';
      if (isset($tree)) {
        $output .= $tree;
      }
      if (isset($links)) {
        $output .= '<div class="page-links clear-block" style="border-top-width:1px;border-top-style:solid;border-top-color:#888888;border-bottom-width:1px;border-bottom-style:solid;border-bottom-color:#888888;text-align:center;">'. $links .'</div>';
      }
      $output .= '</div>';
    }
  }

  return $output;
}

/**
 * Replaces PNG with GIF and removes border.
 */
function jp_mobile_feed_icon($url) {
  if ($image = theme('image', 'sites/all/themes/jp_mobile/feed.gif', t('Syndicate content'), t('Syndicate content'), array('style' => 'border-style:none'))) {
    return '<a href="'. check_url($url) .'" class="feed-icon">'. $image .'</a>';
  }
}

/**
 * Replaces PNG with GIF and removes border.
 */
function jp_mobile_xml_icon($url) {
  if ($image = theme('image', 'sites/all/themes/jp_mobile/xml.gif', t('XML feed'), t('XML feed'), array('style' => 'border-style:none'))) {
    return '<a href="'. check_url($url) .'" class="xml-icon">'. $image .'</a>';
  }
}

/**
 * Replace <div> with <table> since DoCoMo doesn't allow width attribute in div.
 */
function jp_mobile_poll_bar($title, $percentage, $votes, $block) {
  if ($block) {
    $output  = '<div class="text">'. $title .'</div>';
    $output .= '<div class="bar" style="background-color:#dddddd;width:100%;">';
    if ($percentage > 0) {
      $output .= '<table style="width: '. $percentage .'%;background-color:#000000;border-style:none;padding:0px;" class="foreground"><tr><td style="padding:0px;"></td></tr></table>';
    }
    else {
      $output .= '<table style="width:100%;background-color:#dddddd;border-style:none;padding:0px;" class="foreground"><tr><td style="padding:0px;"></td></tr></table>';
    }
    $output .= '</div>';
    $output .= '<div class="percent" style="text-align:right;">'. $percentage .'%</div>';
  }
  else {
    $output  = '<div class="text">'. $title .'</div>';
    $output .= '<div class="bar" style="background-color:#dddddd;width:100%;">';
    if ($percentage > 0) {
      $output .= '<table style="width: '. $percentage .'%;background-color:#000000;border-style:none;padding:0px;" class="foreground"><tr><td style="padding:0px;"></td></tr></table>';
    }
    else {
      $output .= '<table style="width:100%;background-color:#dddddd;border-style:none;padding:0px;" class="foreground"><tr><td style="padding:0px;"></td></tr></table>';
    }
    $output .= '</div>';
    $output .= '<div class="percent" style="text-align:right;">'. $percentage .'% ('. $votes .')</div>';
  }

  return $output;
}

/**
 * Inserts inline CSS.
 */
function jp_mobile_poll_results($title, $results, $votes, $links, $block, $nid, $vote) {
  if ($block) {
    $output .= '<div class="poll">';
    $output .= '<div class="title">'. $title .'</div>';
    $output .= $results;
    $output .= '<div class="total">'. t('Total votes: %votes', array('%votes' => $votes)) .'</div>';
    $output .= '</div>';
    $output .= '<div class="links">'. theme('links', $links) .'</div>';
  }
  else {
    $output .= '<div class="poll">';
    $output .= $results;
    $output .= '<div class="total" style="text-align:center;">'. t('Total votes: %votes', array('%votes' => $votes)) .'</div>';
    if (isset($vote) && $vote > -1 && user_access('cancel own vote')) {
      $output .= drupal_get_form('poll_cancel_form', $nid);
    }
    $output .= '</div>';
  }

  return $output;
}

/**
 * Strips $base_url off links so that session id will be appended to them.
 */
function jp_mobile_search_item($item, $type) {
  global $base_url;
  $output = ' <dt class="title"><a href="'. url(str_replace($base_url .'/', '', check_url($item['link']))) .'">'. check_plain($item['title']) .'</a></dt>';
  $info = array();
  if ($item['type']) {
    $info[] = check_plain($item['type']);
  }
  if ($item['user']) {
    $info[] = $item['user'];
  }
  if ($item['date']) {
    $info[] = format_date($item['date'], 'small');
  }
  if (is_array($item['extra'])) {
    $info = array_merge($info, $item['extra']);
  }
  $output .= ' <dd>'. ($item['snippet'] ? '<p>'. $item['snippet'] .'</p>' : '') .'<p class="search-info">'. implode(' - ', $info) .'</p></dd>';
  return $output;
}

/**
 * Replaces angle quotes with '<' and '>'.
 */
function jp_mobile_pager($tags = array(), $limit = 10, $element = 0, $parameters = array()) {
  global $pager_total;
  $output = '';

  if ($pager_total[$element] > 1) {
    $output .= '<div class="pager">';
    $output .= theme('pager_first', ($tags[0] ? $tags[0] : t('&lt;&lt; first')), $limit, $element, $parameters);
    $output .= theme('pager_previous', ($tags[1] ? $tags[1] : t('&lt; previous')), $limit, $element, 1, $parameters);
    $output .= theme('pager_list', $limit, $element, ($tags[2] ? $tags[2] : 9 ), '', $parameters);
    $output .= theme('pager_next', ($tags[3] ? $tags[3] : t('next &gt;')), $limit, $element, 1, $parameters);
    $output .= theme('pager_last', ($tags[4] ? $tags[4] : t('last &gt;&gt;')), $limit, $element, $parameters);
    $output .= '</div>';

    $output = str_replace('amp;', '', $output);

    return $output;
  }
}

